/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.directory.web.internal.asset;

import com.liferay.asset.kernel.model.BaseAssetRenderer;
import com.liferay.portal.kernel.model.Organization;

import java.util.Locale;

import javax.portlet.PortletRequest;
import javax.portlet.PortletResponse;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * @author Ricardo Couso
 */
public class OrganizationAssetRenderer extends BaseAssetRenderer<Organization> {

	public OrganizationAssetRenderer(Organization organization) {
		_organization = organization;
	}

	@Override
	public Organization getAssetObject() {
		return _organization;
	}

	@Override
	public String getClassName() {
		return Organization.class.getName();
	}

	@Override
	public long getClassPK() {
		return _organization.getPrimaryKey();
	}

	@Override
	public long getGroupId() {
		return _organization.getGroupId();
	}

	@Override
	public String getSummary(
		PortletRequest portletRequest, PortletResponse portletResponse) {

		return _organization.getComments();
	}

	@Override
	public String getTitle(Locale locale) {
		return _organization.getName();
	}

	@Override
	public long getUserId() {
		return _organization.getUserId();
	}

	@Override
	public String getUserName() {
		return _organization.getUserName();
	}

	@Override
	public String getUuid() {
		return _organization.getUuid();
	}

	@Override
	public boolean include(
			HttpServletRequest request, HttpServletResponse response,
			String template)
		throws Exception {

		return false;
	}

	private final Organization _organization;

}